==> apache-seatunnel-2.3.8-src.tar.gz: apache-seatunnel-2.3.8-src/seatunnel-connectors-v2/connector-easysearch/src/main/java/org/apache/seatunnel/connectors/seatunnel/easysearch/dto/IndexInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.easysearch.dto;

import org.apache.seatunnel.shade.com.typesafe.config.Config;

import org.apache.seatunnel.connectors.seatunnel.easysearch.config.SinkConfig;

import lombok.Data;

/** index config by seatunnel */
@Data
public class IndexInfo {

    private String index;
    private String[] primaryKeys;
    private String keyDelimiter;

    public IndexInfo(Config pluginConfig) {
        index = pluginConfig.getString(SinkConfig.INDEX.key());
        if (pluginConfig.hasPath(SinkConfig.PRIMARY_KEYS.key())) {
            primaryKeys =
                    pluginConfig
                            .getStringList(SinkConfig.PRIMARY_KEYS.key())
                            .toArray(new String[0]);
        }
        keyDelimiter = SinkConfig.KEY_DELIMITER.defaultValue();
        if (pluginConfig.hasPath(SinkConfig.KEY_DELIMITER.key())) {
            keyDelimiter = pluginConfig.getString(SinkConfig.KEY_DELIMITER.key());
        }
    }
}

==> apache-seatunnel-2.3.10-src.tar.gz: apache-seatunnel-2.3.10-src/seatunnel-connectors-v2/connector-easysearch/src/main/java/org/apache/seatunnel/connectors/seatunnel/easysearch/dto/IndexInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.easysearch.dto;

import org.apache.seatunnel.api.configuration.ReadonlyConfig;
import org.apache.seatunnel.connectors.seatunnel.easysearch.config.EasysearchSinkCommonOptions;
import org.apache.seatunnel.connectors.seatunnel.easysearch.config.EasysearchSinkOptions;

import lombok.Data;

/** index config by seatunnel */
@Data
public class IndexInfo {

    private String index;
    private String[] primaryKeys;
    private String keyDelimiter;

    public IndexInfo(ReadonlyConfig pluginConfig) {
        index = pluginConfig.get(EasysearchSinkCommonOptions.INDEX);
        if (pluginConfig.getOptional(EasysearchSinkOptions.PRIMARY_KEYS).isPresent()) {
            primaryKeys =
                    pluginConfig.get(EasysearchSinkOptions.PRIMARY_KEYS).toArray(new String[0]);
        }
        keyDelimiter = pluginConfig.get(EasysearchSinkOptions.KEY_DELIMITER);
    }
}
